import { S3Client, GetObjectCommand } from '@aws-sdk/client-s3';
import { S3GetInput } from '../types/UtilTypes';
import { Logger } from '@aws-lambda-powertools/logger';

const logger = new Logger({ serviceName: 'S3' });

const s3Client = new S3Client();
export class S3 {
  static async getObject(data: S3GetInput): Promise<string> {
    const command = new GetObjectCommand(data);
    try {
      const s3Item = await s3Client.send(command);
      if (!s3Item.Body) {
        throw new Error('Get object no found body');
      }
      return s3Item.Body?.transformToString();
    } catch (error) {
      logger.error(error);
      throw new Error(`Error Get object S3: ${error.message}`);
    }
  }
}
